# k3down2

[![Action-CI](https://github.com/pykit3/k3down2/actions/workflows/python-package.yml/badge.svg)](https://github.com/pykit3/k3down2/actions/workflows/python-package.yml)
[![Documentation Status](https://readthedocs.org/projects/k3down2/badge/?version=stable)](https://k3down2.readthedocs.io/en/stable/?badge=stable)
[![Package](https://img.shields.io/pypi/pyversions/k3down2)](https://pypi.org/project/k3down2)

convert markdown segment into easy to transfer media sucha images.

k3down2 is a component of [pykit3] project: a python3 toolkit set.


k3down2 is utility to convert markdown segment into easy to transfer media sucha images.
It depends on:

- pandoc to render markdown snippet to html, such as tables.
- graphviz to render graphviz to image.
- google-chrome to render svg/html to png.
- imagemagick to process images.
- mmdc to convert mermaid chart to svg. See: https://mermaid-js.github.io/mermaid/#





# Install

```
pip install k3down2
```

# Synopsis

```python

```

#   Author

Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>

#   Copyright and License

The MIT License (MIT)

Copyright (c) 2015 Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>


[pykit3]: https://github.com/pykit3